nifigator package
=================

Submodules
----------

nifigator.converters module
---------------------------

.. automodule:: nifigator.converters
   :members:
   :undoc-members:
   :show-inheritance:

nifigator.nifgraph module
-------------------------

.. automodule:: nifigator.nifgraph
   :members:
   :undoc-members:
   :show-inheritance:

nifigator.nifobjects module
---------------------------

.. automodule:: nifigator.nifobjects
   :members:
   :undoc-members:
   :show-inheritance:

nifigator.pdfparser module
--------------------------

.. automodule:: nifigator.pdfparser
   :members:
   :undoc-members:
   :show-inheritance:

nifigator.utils module
----------------------

.. automodule:: nifigator.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nifigator
   :members:
   :undoc-members:
   :show-inheritance:
